identify method

Future<void> identify(
  1. String customerUserId, {
  2. String? iosAppAccountToken,
  3. String? androidObfuscatedAccountId,
})

Use this method for identifying user with it’s user id in your system.

If you don’t have a user id on SDK configuration, you can set it later at any time with .identify() method. The most common cases are after registration/authorization when the user switches from being an anonymous user to an authenticated user.

Parameters:

  • customerUserId: User identifier in your system.
  • iosAppAccountToken: iOS App Account Token (UUID string)
  • androidObfuscatedAccountId: The obfuscated account identifier (use for Android), read more.

Implementation

Future<void> identify(
  String customerUserId, {
  String? iosAppAccountToken,
  String? androidObfuscatedAccountId,
}) {
  final parameters = AdaptyCustomerIdentity(
    iosAppAccountToken,
    androidObfuscatedAccountId,
  );

  return _invokeMethod<void>(
    Method.identify,
    (data) => null,
    {
      Argument.customerUserId: customerUserId,
      if (!parameters.isEmpty) Argument.parameters: parameters.jsonValue,
    },
  );
}