logShowFlow method
Call this method to notify Adapty SDK, that particular paywall was shown to user.
Adapty helps you to measure the performance of the paywalls. We automatically collect all the metrics related to purchases except for paywall views. This is because only you know when the flow was shown to a customer. Whenever you show a flow to your user, call .logShowFlow(flow: flow) to log the event, and it will be accumulated in the flow metrics. Read more on the Adapty Documentation
Parameters:
flow: An AdaptyFlow object.
Implementation
Future<void> logShowFlow({required AdaptyFlow flow}) {
return _invokeMethod<void>(
Method.logShowFlow,
(data) => null,
{
Argument.flow: flow.jsonValue,
},
);
}