onUpdateInstallationDetailsSuccessStream property

Stream<AdaptyInstallationDetails> get onUpdateInstallationDetailsSuccessStream

A broadcast stream of installation details collected by Adapty Attribution.

Emits only when Adapty Attribution is enabled with AdaptyConfiguration.withAdaptyAttributionEnabled; it is off by default.

Implementation

Stream<AdaptyInstallationDetails> get onUpdateInstallationDetailsSuccessStream => _onUpdateInstallationDetailsSuccessController.stream;