AdaptyAccessLevel class

Annotations

Properties

activatedAt → DateTime
Time when this access level was activated.
final
activeIntroductoryOfferType → String?
A type of an active introductory offer. If the value is not null, it means that the offer was applied during the current subscription period.
final
activePromotionalOfferId → String?
An id of active promotional offer.
final
activePromotionalOfferType → String?
A type of an active promotional offer. If the value is not null, it means that the offer was applied during the current subscription period.
final
billingIssueDetectedAt → DateTime?
Time when billing issue was detected. Subscription can still be active. Would be set to null if a charge is made.
final
cancellationReason → String?
A reason why a subscription was cancelled.
final
expiresAt → DateTime?
Time when the access level will expire (could be in the past and could be null for lifetime access).
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier of the access level configured by you in Adapty Dashboard.
final
isActive → bool
true if this access level is active. Generally, you can check this property to determine wether a user has an access to premium features.
final
isInGracePeriod → bool
true if this auto-renewable subscription is in the grace period.
final
isLifetime → bool
true if this access level is active for a lifetime (no expiration date).
final
isRefund → bool
true if this purchase was refunded
final
offerId → String?
Nullable
final
renewedAt → DateTime?
Time when the access level was renewed. It can be null if the purchase was first in chain or it is non-renewing subscription / non-consumable (e.g. lifetime)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startsAt → DateTime?
Time when this access level has started (could be in the future).
final
store → String
A store of the purchase that unlocked this access level.
final
unsubscribedAt → DateTime?
Time when the auto-renewable subscription was cancelled. Subscription can still be active, it just means that auto-renewal turned off. Will be set to null if the user reactivates the subscription.
final
vendorProductId → String
An identifier of a product in a store that unlocked this access level.
final
willRenew → bool
true if this auto-renewable subscription is set to renew.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited