store property
A store of the purchase that unlocked this access level.
Possible values:
app_storeplay_storeadapty
Implementation
final String store;
A store of the purchase that unlocked this access level.
Possible values:
app_storeplay_storeadaptyfinal String store;