AdaptyAndroidSubscriptionUpdateParameters class

Annotations

Constructors

AdaptyAndroidSubscriptionUpdateParameters(String oldSubVendorProductId, AdaptyAndroidSubscriptionUpdateReplacementMode replacementMode)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
oldSubVendorProductId → String
The product id for current subscription to change.
final
replacementMode → AdaptyAndroidSubscriptionUpdateReplacementMode
The proration mode for subscription update. The possible values are: immediateWithTimeProration, immediateAndChargeProratedPrice, immediateWithoutProration, deferred, immediateAndChargeFullPrice.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited