AdaptyErrorCode class

Constructors

AdaptyErrorCode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

activateOnceError → const int
It is not possible to call .activate method more than once.
adaptyNotInitialized → const int
////////////////////////// Custom Android codes. /// //////////////////////////
analyticsDisabled → const int
badRequest → const int
Bad request
billingError → const int
billingServiceDisconnected → const int
billingServiceTimeout → const int
billingServiceUnavailable → const int
billingUnavailable → const int
cantMakePayments → const int
In-App Purchases are not allowed on this device.
cantReadReceipt → const int
Can't find a valid receipt.
clientInvalid → const int
Error code indicating that the client is not allowed to perform the attempted action.
cloudServiceNetworkConnectionFailed → const int
Error code indicating that the device could not connect to the network.
cloudServicePermissionDenied → const int
Error code indicating that the user has not allowed access to Cloud service information.
cloudServiceRevoked → const int
Error code indicating that the user has revoked permission to use this cloud service.
currentSubscriptionToUpdateNotFoundInHistory → const int
decodingFailed → const int
We could not decode the response.
developerError → const int
emptyResult → const int
/////////////////////////// //// Plugin codes. /////// ///////////////////////////
encodingFailed → const int
Parameters encoding failed.
featureNotSupported → const int
fetchTimeoutError → const int
internalPluginError → const int
invalidJson → const int
invalidOfferIdentifier → const int
Error code indicating that the offer identifier is invalid.
invalidOfferPrice → const int
Error code indicating that the price you specified in App Store Connect is no longer valid.
invalidSignature → const int
Error code indicating that the signature in a payment discount is not valid.
itemAlreadyOwned → const int
itemNotOwned → const int
jsException → const int
////////////////////// Custom UI codes. /// ////////////////////// An exception was thrown from JS during AdaptyUI flow execution.
missingOfferParams → const int
Error code indicating that parameters are missing in a payment discount.
networkFailed → const int
Network request failed
noProductIDsFound → const int
/////////////////////////// Custom StoreKit codes. /// /////////////////////////// No In-App Purchase product identifiers were found.
noPurchasesToRestore → const int
No purchases to restore.
notActivated → const int
////////////////////////// Custom network codes. /// ////////////////////////// You need to be authenticated to perform requests.
operationInterrupted → const int
This operation was interrupted by the system.
paymentCancelled → const int
Error code indicating that the user canceled a payment request.
paymentInvalid → const int
Error code indicating that one of the payment parameters was not recognized by the App Store.
paymentNotAllowed → const int
Error code indicating that the user is not allowed to authorize payments.
pendingPurchase → const int
privacyAcknowledgementRequired → const int
Error code indicating that the user has not yet acknowledged Apple’s privacy policy.
productNotFound → const int
productPurchaseFailed → const int
Product purchase failed.
productRequestFailed → const int
Unable to fetch available In-App Purchase products at the moment.
profileWasChanged → const int
The user profile was changed during the operation.
receiveRestoredTransactionsFailed → const int
Error occurred in the process of restoring purchases.
refreshReceiptFailed → const int
Receipt refresh operation has been failed.
serverError → const int
Response code is 429 or 500s.
storeProductNotAvailable → const int
Error code indicating that the requested product is not available in the store.
unauthorizedRequestData → const int
Error code indicating that the app is attempting to use a property for which it does not have the required entitlement.
unknown → const int
/////////////////////////// System StoreKit codes. /// /////////////////////////// Error code indicating that an unknown or unexpected error occurred.
unsupportedData → const int
wrongParam → const int
Wrong parameter was passed.