clientInvalid constant
int
const clientInvalid
Error code indicating that the client is not allowed to perform the attempted action.
Implementation
static const int clientInvalid = 1;
Error code indicating that the client is not allowed to perform the attempted action.
static const int clientInvalid = 1;