paymentCancelled constant
int
const paymentCancelled
Error code indicating that the user canceled a payment request.
Implementation
static const int paymentCancelled = 2;
Error code indicating that the user canceled a payment request.
static const int paymentCancelled = 2;