paymentInvalid constant
int
const paymentInvalid
Error code indicating that one of the payment parameters was not recognized by the App Store.
Implementation
static const int paymentInvalid = 3;
Error code indicating that one of the payment parameters was not recognized by the App Store.
static const int paymentInvalid = 3;