paymentNotAllowed constant
int
const paymentNotAllowed
Error code indicating that the user is not allowed to authorize payments.
Implementation
static const int paymentNotAllowed = 4;
Error code indicating that the user is not allowed to authorize payments.
static const int paymentNotAllowed = 4;