unauthorizedRequestData constant
int
const unauthorizedRequestData
Error code indicating that the app is attempting to use a property for which it does not have the required entitlement.
Implementation
static const int unauthorizedRequestData = 10;