AdaptyExternalAttributionProvider class

Identifier of an external attribution provider.

This is an open wrapper over a raw string so identifiers introduced by future SDK versions remain valid.

Annotations

Constructors

AdaptyExternalAttributionProvider(String rawValue)

Properties

hashCode → int
The hash code for this object.
no setteroverride
rawValue → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override