AdaptyFlow class

Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasViewConfiguration → bool
If true, the flow was built in Adapty Flow Builder and can be rendered with AdaptyUI. Read more here: https://adapty.io/docs/adapty-flow-builder
no setter
instanceIdentity → String
An identifier of a flow, configured in Adapty Dashboard.
final
name → String
A flow name.
final
paywalls → List<AdaptyFlowPaywall>
The paywall variations embedded in this flow.
final
placement → AdaptyPlacement
An AdaptyPlacement object, that contains information about the placement of the flow.
final
productIdentifiers → List<AdaptyProductIdentifier>
Array of related product identifiers, collected from all paywall variations.
no setter
remoteConfig → AdaptyRemoteConfig?
The first remote config of the flow, if present.
no setter
remoteConfigs → List<AdaptyRemoteConfig>
Custom dictionaries configured in Adapty Dashboard for this flow.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variationId → String
An identifier of a variation, used to attribute purchases to this flow.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited