placement property
An AdaptyPlacement object, that contains information about the placement of the flow.
Implementation
final AdaptyPlacement placement;
An AdaptyPlacement object, that contains information about the placement of the flow.
final AdaptyPlacement placement;