placement property
An AdaptyPlacement object, that contains information about the placement of the paywall.
Implementation
final AdaptyPlacement placement;
An AdaptyPlacement object, that contains information about the placement of the paywall.
final AdaptyPlacement placement;