AdaptyNonSubscription class

Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConsumable → bool
true if the product is consumable (should only be processed once).
final
isRefund → bool
true if the purchase was refunded.
final
isSandbox → bool
true if the product was purchased in a sandbox environment.
final
purchasedAt → DateTime
Date when the product was purchased.
final
purchaseId → String
An identifier of the purchase in Adapty. You can use it to ensure that you've already processed this purchase (for example tracking one time products).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → String
A store of the purchase.
final
vendorProductId → String
An identifier of a product in a store that unlocked this subscription.
final
vendorTransactionId → String?
A transaction id of a purchase in a store that unlocked this subscription.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited