AdaptyPrice class

Annotations

Properties

amount → double
Discount price of a product in a local currency.
final
currencyCode → String?
The currency code of the locale used to format the price of the product.
final
currencySymbol → String?
The currency symbol of the locale used to format the price of the product.
final
hashCode → int
The hash code for this object.
no setterinherited
localizedString → String?
A formatted price of a discount for a user's locale.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited