AdaptyProductIdentifier class

Annotations

Constructors

AdaptyProductIdentifier({required String vendorProductId, String? basePlanId, required String adaptyProductId})
const

Properties

basePlanId → String?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendorProductId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

convertProductPurchaseParamsToJson(Map<AdaptyProductIdentifier, AdaptyPurchaseParameters>? productPurchaseParams) → Map<String, dynamic>