AdaptyProductSubscription class

Annotations

Properties

basePlanId → String?
The identifier of the base plan. Android Only.
final
groupIdentifier → String?
The identifier of the subscription group to which the subscription belongs. (Will be nil for iOS version below 12.0 and macOS version below 10.14). iOS Only.
final
hashCode → int
The hash code for this object.
no setterinherited
localizedPeriod → String?
final
offer → AdaptySubscriptionOffer?
final
period → AdaptySubscriptionPeriod
final
renewalType → AdaptyRenewalType
The type of the subscription renewal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited