AdaptyProfile class
- Annotations
Properties
-
accessLevels
→ Map<
String, AdaptyAccessLevel> -
The keys are access level identifiers configured by you in Adapty Dashboard.
The values are Can be null if the customer has no access levels.
final
-
appliedExternalAttributionProviders
→ List<
AdaptyExternalAttributionProvider> -
External attribution providers applied to the profile and available for segmentation.
Known values are available as predefined constants, such as
AdaptyExternalAttributionProvider.appleAds. Other identifiers may be emitted
in future versions, so clients must tolerate unknown values via
AdaptyExternalAttributionProvider.rawValue.
final
-
customAttributes
→ Map<
String, dynamic> -
Previously set user custom attributes with
.updateProfile()method.final - customerUserId → String?
-
An identifier of a user in your system.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTestUser → bool
-
Indicates if the profile belongs to a test devices.
Read more about test devices in Adapty documentation.
final
-
nonSubscriptions
→ Map<
String, List< AdaptyNonSubscription> > -
The keys are product ids from the store. The values are arrays of information about consumables.
Can be null if the customer has no purchases.
final
- profileId → String
-
An identifier of a user in Adapty.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ Map<
String, AdaptySubscription> -
The keys are product ids from a store. The values are information about subscriptions.
Can be null if the customer has no subscriptions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited