isTestUser property
Indicates if the profile belongs to a test devices. Read more about test devices in Adapty documentation.
Implementation
final bool isTestUser;
Indicates if the profile belongs to a test devices. Read more about test devices in Adapty documentation.
final bool isTestUser;