AdaptyProfileParameters class

Constructors

AdaptyProfileParameters()

Properties

analyticsDisabled ↔ bool?
getter/setter pair
appTrackingTransparencyStatus ↔ AdaptyIOSAppTrackingTransparencyStatus?
getter/setter pair
birthday ↔ DateTime?
getter/setter pair
customAttributes → Map<String, dynamic>
no setter
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
gender ↔ AdaptyProfileGender?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastName ↔ String?
getter/setter pair
phoneNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCustomAttribute(String key) → void
setCustomDoubleAttribute(double value, String key) → void
setCustomStringAttribute(String value, String key) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited