AdaptyPromotedProduct class

Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFamilyShareable → bool
A Boolean value that indicates whether the product is available for family sharing in App Store Connect.
final
localizedDescription → String
A description of the product.
final
localizedTitle → String
The name of the product.
final
price → AdaptyPrice
The object which represents the main price for the product.
final
regionCode → String?
The region code of the locale used to format the price of the product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → AdaptyProductSubscription?
Detailed information about subscription (intro, offers, etc.)
final
vendorProductId → String
Unique identifier of a product from App Store Connect.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited