AdaptyPurchaseParameters class

Constructors

AdaptyPurchaseParameters({AdaptyAndroidSubscriptionUpdateParameters? subscriptionUpdateParams = null, bool? isOfferPersonalized = null})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOfferPersonalized ↔ bool?
Specifies whether the offer is personalized to the buyer (use for Android).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionUpdateParams ↔ AdaptyAndroidSubscriptionUpdateParameters?
Used to upgrade or downgrade a subscription (use for Android).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited