isOfferPersonalized property
Specifies whether the offer is personalized to the buyer (use for Android).
Implementation
bool? isOfferPersonalized;
Specifies whether the offer is personalized to the buyer (use for Android).
bool? isOfferPersonalized;