AdaptySubscription class

Annotations

Properties

activatedAt → DateTime
Time when the subscription was activated.
final
activeIntroductoryOfferType → String?
A type of an active introductory offer. If the value is not null, it means that the offer was applied during the current subscription period.
final
activePromotionalOfferId → String?
An id of active promotional offer.
final
activePromotionalOfferType → String?
A type of an active promotional offer. If the value is not null, it means that the offer was applied during the current subscription period.
final
billingIssueDetectedAt → DateTime?
Time when a billing issue was detected. Subscription can still be active.
final
cancellationReason → String?
A reason why a subscription was cancelled.
final
expiresAt → DateTime?
Time when the access level will expire (could be in the past and could be null for lifetime access).
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
True if the subscription is active
final
isInGracePeriod → bool
Whether the auto-renewable subscription is in a grace period.
final
isLifetime → bool
True if the subscription is active for a lifetime (no expiration date)
final
isRefund → bool
true if the purchase was refunded.
final
isSandbox → bool
true if the product was purchased in a sandbox environment.
final
offerId → String?
Nullable
final
renewedAt → DateTime?
Time when the subscription was renewed. It can be null if the purchase was first in chain or it is non-renewing subscription.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startsAt → DateTime?
Time when the subscription has started (could be in the future).
final
store → String
A store of the purchase.
final
unsubscribedAt → DateTime?
Time when the auto-renewable subscription was cancelled. Subscription can still be active, it means that auto-renewal is turned off. Would be null if a user reactivates the subscription.
final
vendorOriginalTransactionId → String
An original transaction id of the purchase in a store that unlocked this subscription. For auto-renewable subscription, this will be an id of the first transaction in this subscription.
final
vendorProductId → String
An identifier of a product in a store that unlocked this subscription.
final
vendorTransactionId → String
A transaction id of a purchase in a store that unlocked this subscription.
final
willRenew → bool
true if the auto-renewable subscription is set to renew
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited