renewedAt property
Time when the subscription was renewed. It can be null if the purchase was first in chain or it is non-renewing subscription.
Nullable
Implementation
final DateTime? renewedAt;
Time when the subscription was renewed. It can be null if the purchase was first in chain or it is non-renewing subscription.
Nullable
final DateTime? renewedAt;