AdaptySubscriptionPhase class

Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
final
localizedNumberOfPeriods → String?
A formatted number of periods of a discount for a user's locale.
final
localizedSubscriptionPeriod → String?
A formatted subscription period of a discount for a user's locale.
final
numberOfPeriods → int
A number of periods this product discount is available
final
paymentMode → AdaptyPaymentMode
A payment mode for this product discount.
final
price → AdaptyPrice
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod → AdaptySubscriptionPeriod
An information about period for a product discount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited