AdaptyUI class

Constructors

AdaptyUI()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFlowView({required AdaptyFlow flow, String? locale, String? customLayoutId, Duration? loadTimeout, bool preloadProducts = false, bool androidEnableSafeArea = true, Map<String, String>? customTags, Map<String, DateTime>? customTimers, Map<String, AdaptyCustomAsset>? customAssets, Map<AdaptyProductIdentifier, AdaptyPurchaseParameters>? productPurchaseParams}) → Future<AdaptyUIFlowView>
Right after receiving AdaptyFlow, you can create the corresponding AdaptyUIFlowView to present it afterwards.
createOnboardingView({required AdaptyOnboarding onboarding, AdaptyWebPresentation externalUrlsPresentation = AdaptyWebPresentation.inAppBrowser}) → Future<AdaptyUIOnboardingView>
dismissFlowView(AdaptyUIFlowView view, {bool destroy = true}) → Future<void>
Call this function if you wish to dismiss the view.
dismissOnboardingView(AdaptyUIOnboardingView view) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openUrl(String url, {AdaptyWebPresentation openIn = AdaptyWebPresentation.externalBrowser}) → Future<void>
Opens a URL natively (external or in-app browser). Backs the default handling of the flow open_url action; can also be called directly.
presentFlowView(AdaptyUIFlowView view, {AdaptyUIIOSPresentationStyle iosPresentationStyle = AdaptyUIIOSPresentationStyle.fullScreen}) → Future<void>
Call this function if you wish to present the view.
presentOnboardingView(AdaptyUIOnboardingView view, {AdaptyUIIOSPresentationStyle iosPresentationStyle = AdaptyUIIOSPresentationStyle.fullScreen}) → Future<void>
Call this function if you wish to present the view.
registerFlowEventsListener(AdaptyUIFlowsEventsObserver observer, String viewId) → void
registerOnboardingEventsListener(AdaptyUIOnboardingsEventsObserver observer, String viewId) → void
requestAppReview() → Future<void>
Requests the native in-app review prompt (StoreKit on iOS). Best-effort: the OS decides whether to actually show it. Backs the default handling of the flow app-review request; can also be called directly.
setFlowsEventsObserver(AdaptyUIFlowsEventsObserver? observer) → void
Use this method to set the AdaptyUI flows events observer.
setObserverModeResolver(AdaptyUIObserverModeResolver resolver) → void
Use this method to set the AdaptyUI observer mode resolver.
setOnboardingsEventsObserver(AdaptyUIOnboardingsEventsObserver? observer) → void
Use this method to set the AdaptyUI onboardings events observer.
setSystemRequestsHandler(AdaptyUISystemRequestsHandler handler) → void
Use this method to set the AdaptyUI system requests handler.
showDialog(String viewId, {required String title, required String content, required String primaryActionTitle, String? secondaryActionTitle}) → Future<AdaptyUIDialogActionType>
Call this function if you wish to present the dialog.
toString() → String
A string representation of this object.
inherited
unregisterFlowEventsListener(String viewId) → void
unregisterOnboardingEventsListener(String viewId) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited