AdaptyUIFlowPlatformView class

Inheritance

Constructors

AdaptyUIFlowPlatformView({Key? key, required AdaptyFlow flow, String? locale, String? customLayoutId, bool androidEnableSafeArea = false, Map<String, String>? customTags, Map<String, DateTime>? customTimers, Map<String, AdaptyCustomAsset>? customAssets, Map<AdaptyProductIdentifier, AdaptyPurchaseParameters>? productPurchaseParams, void onDidAppear(AdaptyUIFlowView)?, void onDidDisappear(AdaptyUIFlowView)?, void onDidPerformAction(AdaptyUIFlowView, AdaptyUIAction)?, void onDidSelectProduct(AdaptyUIFlowView, String)?, void onDidStartPurchase(AdaptyUIFlowView, AdaptyPaywallProduct)?, void onDidFinishPurchase(AdaptyUIFlowView, AdaptyPaywallProduct, AdaptyPurchaseResult)?, void onDidFailPurchase(AdaptyUIFlowView, AdaptyPaywallProduct, AdaptyError)?, void onDidStartRestore(AdaptyUIFlowView)?, void onDidFinishRestore(AdaptyUIFlowView, AdaptyProfile)?, void onDidFailRestore(AdaptyUIFlowView, AdaptyError)?, void onDidReceiveError(AdaptyUIFlowView, AdaptyError)?, void onDidFailLoadingProducts(AdaptyUIFlowView, AdaptyError)?, void onDidFinishWebPaymentNavigation(AdaptyUIFlowView, AdaptyPaywallProduct?, AdaptyError?)?, void onDidReceiveAnalyticEvent(AdaptyUIFlowView, String, Map<String, dynamic>)?})
const

Properties

androidEnableSafeArea → bool
Android only. If true, the flow view applies the safe-area insets as paddings. Has no effect on iOS. Defaults to false for the embedded view, which is usually hosted inside a widget tree that already manages safe-area insets (e.g. a SafeArea), so native paddings would double up.
final
customAssets → Map<String, AdaptyCustomAsset>?
final
customLayoutId → String?
The custom ID of a grid configured for this flow in the Adapty Flow Builder, to render instead of the grid selected automatically for the current device.
final
customTags → Map<String, String>?
final
customTimers → Map<String, DateTime>?
final
flow → AdaptyFlow
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → String?
The identifier of the localization to render the flow with, e.g. en, es, fr.
final
onDidAppear → void Function(AdaptyUIFlowView)?
final
onDidDisappear → void Function(AdaptyUIFlowView)?
final
onDidFailLoadingProducts → void Function(AdaptyUIFlowView, AdaptyError)?
final
onDidFailPurchase → void Function(AdaptyUIFlowView, AdaptyPaywallProduct, AdaptyError)?
final
onDidFailRestore → void Function(AdaptyUIFlowView, AdaptyError)?
final
onDidFinishPurchase → void Function(AdaptyUIFlowView, AdaptyPaywallProduct, AdaptyPurchaseResult)?
final
onDidFinishRestore → void Function(AdaptyUIFlowView, AdaptyProfile)?
final
onDidFinishWebPaymentNavigation → void Function(AdaptyUIFlowView, AdaptyPaywallProduct?, AdaptyError?)?
final
onDidPerformAction → void Function(AdaptyUIFlowView, AdaptyUIAction)?
final
onDidReceiveAnalyticEvent → void Function(AdaptyUIFlowView, String, Map<String, dynamic>)?
final
onDidReceiveError → void Function(AdaptyUIFlowView, AdaptyError)?
final
onDidSelectProduct → void Function(AdaptyUIFlowView, String)?
final
onDidStartPurchase → void Function(AdaptyUIFlowView, AdaptyPaywallProduct)?
final
onDidStartRestore → void Function(AdaptyUIFlowView)?
final
productPurchaseParams → Map<AdaptyProductIdentifier, AdaptyPurchaseParameters>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AdaptyUIFlowPlatformView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited