AdaptyUIFlowView class
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier of the view.
final
- locale → String?
-
The localization the view was actually built with.
final
- placementId → String
-
The identifier of placement.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variationId → String
-
The identifier of flow variation.
final
Methods
-
dismiss(
{bool destroy = true}) → Future< void> - Call this function if you wish to dismiss the view.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
{AdaptyUIIOSPresentationStyle iosPresentationStyle = AdaptyUIIOSPresentationStyle.fullScreen}) → Future< void> - Call this function if you wish to present the view.
-
showDialog(
{required String title, required String content, required String primaryActionTitle, String? secondaryActionTitle}) → Future< AdaptyUIDialogActionType> - Call this function if you wish to present the dialog.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited