AdaptyUIFlowsEventsObserver class abstract

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flowViewDidAppear(AdaptyUIFlowView view) → void
This method is invoked when the flow view was presented.
flowViewDidDisappear(AdaptyUIFlowView view) → void
This method is invoked when the flow view was dismissed.
flowViewDidFailLoadingProducts(AdaptyUIFlowView view, AdaptyError error) → void
This method is invoked in case of errors during the products loading process.
flowViewDidFailPurchase(AdaptyUIFlowView view, AdaptyPaywallProduct product, AdaptyError error) → void
This method is invoked when the purchase process fails.
flowViewDidFailRestore(AdaptyUIFlowView view, AdaptyError error) → void
This method is invoked when the restore process fails.
flowViewDidFinishPurchase(AdaptyUIFlowView view, AdaptyPaywallProduct product, AdaptyPurchaseResult purchaseResult) → void
This method is invoked when a successful purchase is made.
flowViewDidFinishRestore(AdaptyUIFlowView view, AdaptyProfile profile) → void
This method is invoked when a successful restore is made.
flowViewDidFinishWebPaymentNavigation(AdaptyUIFlowView view, AdaptyPaywallProduct? product, AdaptyError? error) → void
This method is invoked when the web payment navigation is finished.
flowViewDidPerformAction(AdaptyUIFlowView view, AdaptyUIAction action) → void
If the user presses the close button, this method will be invoked.
flowViewDidReceiveAnalyticEvent(AdaptyUIFlowView view, String name, Map<String, dynamic> params) → void
This method is invoked when the flow view emits an analytic event.
flowViewDidReceiveError(AdaptyUIFlowView view, AdaptyError error) → void
This method will be invoked in case of errors during the screen rendering process.
flowViewDidSelectProduct(AdaptyUIFlowView view, String productId) → void
If product was selected for purchase (by user or by system), this method will be invoked.
flowViewDidStartPurchase(AdaptyUIFlowView view, AdaptyPaywallProduct product) → void
If user initiates the purchase process, this method will be invoked.
flowViewDidStartRestore(AdaptyUIFlowView view) → void
If user initiates the restore process, this method will be invoked.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited