flowViewDidAppear method
This method is invoked when the flow view was presented.
**Parameters**
- [view]: an [AdaptyUIFlowView] within which the event occurred.
Implementation
void flowViewDidAppear(AdaptyUIFlowView view) {}
This method is invoked when the flow view was presented.
**Parameters**
- [view]: an [AdaptyUIFlowView] within which the event occurred.
void flowViewDidAppear(AdaptyUIFlowView view) {}