flowViewDidDisappear method
This method is invoked when the flow view was dismissed.
**Parameters**
- [view]: an [AdaptyUIFlowView] within which the event occurred.
Implementation
void flowViewDidDisappear(AdaptyUIFlowView view) {}
This method is invoked when the flow view was dismissed.
**Parameters**
- [view]: an [AdaptyUIFlowView] within which the event occurred.
void flowViewDidDisappear(AdaptyUIFlowView view) {}