flowViewDidFinishPurchase abstract method
void
flowViewDidFinishPurchase(
- AdaptyUIFlowView view,
- AdaptyPaywallProduct product,
- AdaptyPurchaseResult purchaseResult
This method is invoked when a successful purchase is made.
There is no default implementation; implement this method to decide what
happens after a successful purchase (e.g. continue the flow or call view.dismiss()).
Parameters
view: an AdaptyUIFlowView within which the event occurred.product: an AdaptyPaywallProduct of the purchase.purchaseResult: an AdaptyPurchaseResult object containing the information about successful purchase or it cancellation.
Implementation
void flowViewDidFinishPurchase(
AdaptyUIFlowView view,
AdaptyPaywallProduct product,
AdaptyPurchaseResult purchaseResult,
);