flowViewDidFinishRestore abstract method

void flowViewDidFinishRestore(
  1. AdaptyUIFlowView view,
  2. AdaptyProfile profile
)

This method is invoked when a successful restore is made.

Check if the AdaptyProfile object contains the desired access level, and if so, the controller can be dismissed.

view.dismiss()

Parameters

Implementation

void flowViewDidFinishRestore(AdaptyUIFlowView view, AdaptyProfile profile);