flowViewDidStartRestore method
If user initiates the restore process, this method will be invoked.
Parameters
view: an AdaptyUIFlowView within which the event occurred.
Implementation
void flowViewDidStartRestore(AdaptyUIFlowView view) {}
If user initiates the restore process, this method will be invoked.
Parameters
view: an AdaptyUIFlowView within which the event occurred.void flowViewDidStartRestore(AdaptyUIFlowView view) {}