AdaptyUIObserverModeResolver class abstract

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observerModeDidInitiatePurchase(AdaptyUIFlowView view, AdaptyPaywallProduct product, void onStartPurchase(), void onFinishPurchase()) → void
observerModeDidInitiateRestore(AdaptyUIFlowView view, void onStartRestore(), void onFinishRestore()) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited