AdaptyUIOnboardingPlatformView class

Inheritance
Annotations
  • @Deprecated('Starting Adapty SDK 4.0.0, Onboarding Feature is deprecated. Please consider migrating to Flows')

Constructors

AdaptyUIOnboardingPlatformView({Key? key, required AdaptyOnboarding onboarding, AdaptyWebPresentation externalUrlsPresentation = AdaptyWebPresentation.inAppBrowser, void onDidFinishLoading(AdaptyUIOnboardingMeta)?, void onDidFailWithError(AdaptyError)?, void onCloseAction(AdaptyUIOnboardingMeta, String)?, void onPaywallAction(AdaptyUIOnboardingMeta, String)?, void onCustomAction(AdaptyUIOnboardingMeta, String)?, void onStateUpdatedAction(AdaptyUIOnboardingMeta, String, AdaptyOnboardingsStateUpdatedParams)?, void onAnalyticsEvent(AdaptyUIOnboardingMeta, AdaptyOnboardingsAnalyticsEvent)?})
const

Properties

externalUrlsPresentation → AdaptyWebPresentation
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAnalyticsEvent → void Function(AdaptyUIOnboardingMeta, AdaptyOnboardingsAnalyticsEvent)?
final
onboarding → AdaptyOnboarding
final
onCloseAction → void Function(AdaptyUIOnboardingMeta, String)?
final
onCustomAction → void Function(AdaptyUIOnboardingMeta, String)?
final
onDidFailWithError → void Function(AdaptyError)?
final
onDidFinishLoading → void Function(AdaptyUIOnboardingMeta)?
final
onPaywallAction → void Function(AdaptyUIOnboardingMeta, String)?
final
onStateUpdatedAction → void Function(AdaptyUIOnboardingMeta, String, AdaptyOnboardingsStateUpdatedParams)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AdaptyUIOnboardingPlatformView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited