AdaptyUIOnboardingView class
- Annotations
-
- @Deprecated('Starting Adapty SDK 4.0.0, Onboarding Feature is deprecated. Please consider migrating to Flows')
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier of the view.
final
- isNativeRendering → bool
-
Whether the onboarding is rendered as a native modal view.
no setter
- isWidgetRendering → bool
-
Whether the onboarding is rendered in a Flutter widget.
no setter
- placementId → String
-
The identifier of paywall.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variationId → String
-
The identifier of paywall variation.
final
Methods
-
dismiss(
) → Future< void> - Call this function if you wish to dismiss the view.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
present(
{AdaptyUIIOSPresentationStyle iosPresentationStyle = AdaptyUIIOSPresentationStyle.fullScreen}) → Future< void> - Call this function if you wish to present the view.
-
showDialog(
{required String title, required String content, required String primaryActionTitle, String? secondaryActionTitle}) → Future< AdaptyUIDialogActionType> - Call this function if you wish to present the dialog.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited