AdaptyUISystemRequestsHandler class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleAppReviewRequest(
AdaptyUIFlowView view) → Future< void> -
handlePermission(
AdaptyUIFlowView view, AdaptyUIPermission permission, Map< String, String> ? customArgs) → Future<AdaptyUIPermissionResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited