OpenUrlAction class final

Some button which contains url (e.g. Terms or Privacy & Policy) was pressed by user

Inheritance

Constructors

OpenUrlAction(String url, AdaptyWebPresentation openIn)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
openIn → AdaptyWebPresentation
Where the URL should be opened — in an external browser or in an in-app browser.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited