onUpdateInstallationDetailsFailStream property
Stream<AdaptyError>
get
onUpdateInstallationDetailsFailStream
A broadcast stream of errors from collecting installation details.
Emits only when Adapty Attribution is enabled with AdaptyConfiguration.withAdaptyAttributionEnabled; it is off by default.
Implementation
Stream<AdaptyError> get onUpdateInstallationDetailsFailStream => _onUpdateInstallationDetailsFailController.stream;