AdaptyConfiguration class

Constructors

AdaptyConfiguration({required String apiKey})
Initializes the configuration with the given API key.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withActivateUI(bool activateUI) → void
withAdaptyAttributionEnabled(bool adaptyAttributionEnabled) → void
Parameters:
withAppleClearDataOnBackup(bool appleClearDataOnBackup) → void
Parameters:
withAppleIdfaCollectionDisabled(bool appleIdfaCollectionDisabled) → void
Parameters:
withBackendProxyHost(String backendProxyHost) → void
withBackendProxyPort(int backendProxyPort) → void
withCrossPlatformSDKName(String crossPlatformSDKName) → void
withCrossPlatformSDKVersion(String crossPlatformSDKVersion) → void
withCustomerUserId(String customerUserId, {String? iosAppAccountToken, String? androidObfuscatedAccountId}) → void
Parameters:
withGoogleAdvertisingIdCollectionDisabled(bool googleAdvertisingIdCollectionDisabled) → void
Parameters:
withGoogleEnablePendingPrepaidPlans(bool googleEnablePendingPrepaidPlans) → void
Parameters:
withGoogleLocalAccessLevelAllowed(bool googleLocalAccessLevelAllowed) → void
withIpAddressCollectionDisabled(bool ipAddressCollectionDisabled) → void
Parameters:
withLogLevel(AdaptyLogLevel logLevel) → void
Parameters:
withMediaCacheConfiguration(AdaptyUIMediaCacheConfiguration mediaCacheConfiguration) → void
withObserverMode(bool observerMode) → void
Parameters:
withServerCluster(AdaptyServerCluster serverCluster) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited