AdaptyFlowPaywall class
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceIdentity → String
-
An identifier of a paywall, configured in Adapty Dashboard.
final
- name → String
-
A paywall name.
final
- placement → AdaptyPlacement
-
An
AdaptyPlacementobject, that contains information about the placement of the paywall.final -
productIdentifiers
→ List<
AdaptyProductIdentifier> -
Array of related product identifiers.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variationId → String
-
An identifier of a variation, used to attribute purchases to this paywall.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited