flowViewDidFinishRestore abstract method
This method is invoked when a successful restore is made.
Check if the AdaptyProfile object contains the desired access level, and if so, the controller can be dismissed.
view.dismiss()
Parameters
view: an AdaptyUIFlowView within which the event occurred.profile: an AdaptyProfile object containing up to date information about the user.
Implementation
void flowViewDidFinishRestore(AdaptyUIFlowView view, AdaptyProfile profile);