flowViewDidReceiveAnalyticEvent method
void
flowViewDidReceiveAnalyticEvent(
- AdaptyUIFlowView view,
- String name,
- Map<
String, dynamic> params
This method is invoked when the flow view emits an analytic event.
Parameters
view: an AdaptyUIFlowView within which the event occurred.name: the name of the analytic event.params: a map containing the parameters of the analytic event.
Implementation
void flowViewDidReceiveAnalyticEvent(AdaptyUIFlowView view, String name, Map<String, dynamic> params) {}