AdaptyUIOnboardingMeta class
- Annotations
-
- @Deprecated('Starting Adapty SDK 4.0.0, Onboarding Feature is deprecated. Please consider migrating to Flows')
- @immutable
Constructors
- AdaptyUIOnboardingMeta({required String onboardingId, required String screenClientId, required int screenIndex, required int screensTotal})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onboardingId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenClientId → String
-
final
- screenIndex → int
-
final
- screensTotal → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited