showDialog method
Call this function if you wish to present the dialog.
Parameters
title: The title of the dialog.content: Descriptive text that provides additional details about the reason for the dialog.primaryActionTitle: The action title to display as part of the dialog. If you provide two actions, be sure thedefaultActioncancels the operation and leaves things unchanged.secondaryActionTitle: The secondary action title to display as part of the dialog.
Implementation
Future<AdaptyUIDialogActionType> showDialog({
required String title,
required String content,
required String primaryActionTitle,
String? secondaryActionTitle,
}) =>
AdaptyUI().showDialog(
id,
title: title,
content: content,
primaryActionTitle: primaryActionTitle,
secondaryActionTitle: secondaryActionTitle,
);